/// <reference types="node" />
import { EventEmitter } from 'events';
import { CompletionItem, Location, Position } from 'vscode-languageserver';
import { BrsFile } from './files/BrsFile';
import { XmlFile } from './files/XmlFile';
import { CallableContainer, Diagnostic, File } from './interfaces';
import { Program } from './Program';
/**
 * A class to keep track of all declarations within a given context (like global scope, component scope)
 */
export declare class Context {
    name: string;
    private matcher;
    constructor(name: string, matcher: (file: File) => boolean | void);
    /**
     * Indicates whether this context needs to be validated.
     * Will be true when first constructed, or anytime one of its watched files is added, changed, or removed
     */
    isValidated: boolean;
    protected program: Program;
    protected programHandles: (() => void)[];
    /**
     * Attach the context to a program. This allows the context to monitor file adds, changes, and removals, and respond accordingly
     * @param program
     */
    attachProgram(program: Program): void;
    /**
     * Clean up all event handles
     */
    dispose(): void;
    private parentContextHandles;
    attachParentContext(parent: Context): void;
    detachParent(): void;
    /**
     * A parent context that this context inherits all things from.
     */
    parentContext: Context;
    /**
     * Determine if this file should
     * @param filePath
     */
    shouldIncludeFile(file: File): boolean;
    files: {
        [filePath: string]: ContextFile;
    };
    /**
     * Get the list of errors for this context. It's calculated on the fly, so
     * call this sparingly.
     */
    getDiagnostics(): Diagnostic[];
    /**
     * The list of diagnostics found specifically for this context. Individual file diagnostics are stored on the files themselves.
     */
    protected diagnostics: Diagnostic[];
    /**
     * Get the list of callables available in this context (either declared in this context or in a parent context)
     */
    getAllCallables(): CallableContainer[];
    /**
     * Get the callable with the specified name.
     * If there are overridden callables with the same name, the closest callable to this context is returned
     * @param name
     */
    getCallableByName(name: string): import("./interfaces").Callable;
    /**
     * Get the list of callables explicitly defined in files in this context.
     * This excludes ancestor callables
     */
    getOwnCallables(): CallableContainer[];
    emitter: EventEmitter;
    on(eventName: 'invalidated', callback: () => void): any;
    protected emit(name: 'invalidated'): any;
    /**
     * Add a file to the program.
     * @param filePath
     * @param fileContents
     */
    addOrReplaceFile(file: BrsFile | XmlFile): void;
    /**
     * Remove the file from this context.
     * If the file doesn't exist, the method exits immediately, but does not throw an error.
     * @param file
     * @param emitRemovedEvent - if false, the 'remove-file' event will not be emitted
     */
    removeFile(file: File): void;
    validate(): void;
    /**
     * Detect calls to functions with the incorrect number of parameters
     * @param file
     * @param callableContainersByLowerName
     */
    private diagnosticDetectFunctionCallsWithWrongParamCount;
    /**
     * Detect local variables (function scope) that have the same name as context calls
     * @param file
     * @param callablesByLowerName
     */
    private diagnosticDetectShadowedLocalVars;
    /**
     * Detect calls to functions that are not defined in this context
     * @param file
     * @param callablesByLowerName
     */
    private diagnosticDetectCallsToUnknownFunctions;
    /**
     * Create diagnostics for any duplicate function declarations
     * @param callablesByLowerName
     */
    private diagnosticFindDuplicateFunctionDeclarations;
    /**
     * Find the file with the specified relative path
     * @param relativePath
     */
    protected getFileByRelativePath(relativePath: string): ContextFile;
    /**
     * Determine if the context already has this file in its files list
     * @param file
     */
    hasFile(pathAbsolute: string): any;
    hasFile(file: BrsFile | XmlFile): any;
    /**
     * Get all callables as completionItems
     */
    getCallablesAsCompletions(): CompletionItem[];
    /**
     * Get the definition (where was this thing first defined) of the symbol under the position
     */
    getDefinition(file: BrsFile | XmlFile, position: Position): Location[];
}
declare class ContextFile {
    file: BrsFile | XmlFile;
    constructor(file: BrsFile | XmlFile);
}
export {};
