import { CompletionItem, Location, Position } from 'vscode-languageserver';
import { BrsConfig } from './BrsConfig';
import { Context } from './Context';
import { BrsFile } from './files/BrsFile';
import { XmlFile } from './files/XmlFile';
import { Diagnostic } from './interfaces';
export declare class Program {
    /**
     * The root directory for this program
     */
    options: BrsConfig;
    constructor(
    /**
     * The root directory for this program
     */
    options: BrsConfig);
    /**
     * A list of functions that will be used to load file contents.
     * In most cases, there will only be the "read from filesystem" resolver.
     * However, when running inside the LanguageServer, a second resolver will be added
     * to resolve the opened file contents from memory instead of going to disk.
     */
    fileResolvers: FileResolver[];
    /**
     * Get the contents of the specified file as a string.
     * This walks backwards through the file resolvers until we get a value.
     * This allow the language server to provide file contents directly from memory.
     */
    getFileContents(pathAbsolute: string): Promise<string>;
    /**
     * A context that contains all platform-provided functions.
     * All contexts should directly or indirectly inherit from this context
     */
    platformContext: Context;
    /**
     * The full path to the root of the brightscript project (where the manifest file lives)
     */
    rootDir: string;
    /**
     * A set of diagnostics. This does not include any of the context diagnostics.
     * Should only be set from `this.validate()`
     */
    private diagnostics;
    /**
     * Get the list of errors for the entire program. It's calculated on the fly
     * by walking through every file, so call this sparingly.
     */
    getDiagnostics(): Diagnostic[];
    /**
     * A map of every file loaded into this program
     */
    files: {
        [filePath: string]: BrsFile | XmlFile;
    };
    contexts: {
        [name: string]: Context;
    };
    /**
     * Determine if the specified file is loaded in this program right now.
     * @param filePath
     */
    hasFile(filePath: string): boolean;
    /**
     * Add and parse all of the provided files.
     * Files that are already loaded will be replaced by the latest
     * contents from the file system.
     * @param filePaths
     */
    addOrReplaceFiles(filePaths: string[]): Promise<void>;
    /**
     * Load a file into the program. If that file already exists, it is replaced.
     * If file contents are provided, those are used, Otherwise, the file is loaded from the file system
     * @param pathAbsolute
     * @param fileContents
     */
    addOrReplaceFile(pathAbsolute: string, fileContents?: string): Promise<BrsFile | XmlFile>;
    private emitter;
    on(name: 'file-added', callback: (file: BrsFile | XmlFile) => void): any;
    on(name: 'file-removed', callback: (file: BrsFile | XmlFile) => void): any;
    protected emit(name: 'file-added', file: BrsFile | XmlFile): any;
    protected emit(name: 'file-removed', file: BrsFile | XmlFile): any;
    /**
     * Get a file with the specified pkg path.
     * If not found, return undefined
     */
    getFileByPkgPath(pkgPath: string): BrsFile | XmlFile;
    /**
     * Remove a set of files from the program
     * @param filePaths
     */
    removeFiles(filePaths: string[]): void;
    /**
     * Remove a file from the program
     * @param filePath
     */
    removeFile(filePath: string): void;
    /**
     * Traverse the entire project, and validate all contexts
     */
    validate(): Promise<void>;
    /**
     * Get the file at the given path
     * @param pathAbsolute
     */
    private getFile;
    /**
     * Get a list of all contexts the file is loaded into
     * @param file
     */
    getContextsForFile(file: XmlFile | BrsFile): Context[];
    /**
     * Find all available completion items at the given position
     * @param pathAbsolute
     * @param lineIndex
     * @param columnIndex
     */
    getCompletions(pathAbsolute: string, position: Position): CompletionItem[];
    /**
     * Given a position in a file, if the position is sitting on some type of identifier,
     * go to the definition of that identifier (where this thing was first defined)
     */
    getDefinition(pathAbsolute: string, position: Position): Location[];
    getHover(pathAbsolute: string, position: Position): import("vscode-languageserver-types").Hover;
    dispose(): void;
}
export declare type FileResolver = (pathAbsolute: string) => string | undefined | Thenable<string | undefined>;
