import * as brs from 'brs';
import { DiagnosticSeverity, Position, Range } from 'vscode-languageserver';
import { BrsConfig } from './BrsConfig';
import { CallableContainer, Diagnostic, ValueKind } from './interfaces';
import { BrsType } from './types/BrsType';
export declare class Util {
    log(...args: any[]): void;
    clearConsole(): void;
    /**
     * Determine if the file exists
     * @param filePath
     */
    fileExists(filePath: string): Promise<{}>;
    /**
     * Load a file from disc into a string
     * @param filePath
     */
    getFileContents(filePath: string): Promise<string>;
    /**
     * Make the path absolute, and replace all separators with the current OS's separators
     * @param filePath
     */
    normalizeFilePath(filePath: string): string;
    /**
     * Find the path to the config file.
     * If the config file path doesn't exist
     * @param configFilePath
     */
    getConfigFilePath(cwd?: string): Promise<string>;
    /**
     * Load the contents of a config file.
     * If the file extends another config, this will load the base config as well.
     * @param configFilePath
     * @param parentProjectPaths
     */
    loadConfigFile(configFilePath: string, parentProjectPaths?: string[]): Promise<BrsConfig>;
    /**
     * Given a BrsConfig object, start with defaults,
     * merge with brsconfig.json and the provided options.
     * @param config
     */
    normalizeAndResolveConfig(config: BrsConfig): Promise<BrsConfig>;
    /**
     * Set defaults for any missing items
     * @param config
     */
    normalizeConfig(config: BrsConfig): BrsConfig;
    /**
     * Get the root directory from options.
     * Falls back to options.cwd.
     * Falls back to process.cwd
     * @param options
     */
    getRootDir(options: BrsConfig): string;
    /**
     * Format a string with placeholders replaced by argument indexes
     * @param subject
     * @param params
     */
    stringFormat(subject: string, ...args: any[]): string;
    valueKindToBrsType(kind: ValueKind): BrsType;
    /**
     * Convert a 1-indexed brs Location to a 0-indexed vscode range
     * @param location
     */
    locationToRange(location: brs.lexer.Location): Range;
    /**
     * Compute the range of a function's body
     * @param func
     */
    getBodyRangeForFunc(func: brs.parser.Expr.Function): Range;
    /**
     * Given a list of callables, get that as a a dictionary indexed by name.
     * @param callables
     */
    getCallableContainersByLowerName(callables: CallableContainer[]): {
        [name: string]: CallableContainer[];
    };
    /**
     *
     * @param severity
     */
    severityToDiagnostic(severity: 'hint' | 'information' | 'warning' | 'error'): DiagnosticSeverity;
    /**
     * Split a file by newline characters (LF or CRLF)
     * @param text
     */
    getLines(text: string): string[];
    /**
     * Given an absollute path to a source file, and a target path,
     * compute the pkg path for the target relative to the source file's location
     * @param containingFilePathAbsolute
     * @param targetPath
     */
    getPkgPathFromTarget(containingFilePathAbsolute: string, targetPath: string): string;
    /**
     * Compute the relative path from the source file to the target file
     * @param pkgSourcePathAbsolute  - the absolute path to the source relative to the package location
     * @param pkgTargetPathAbsolute  - the absolute path ro the target relative to the package location
     */
    getRelativePath(pkgSourcePathAbsolute: string, pkgTargetPathAbsolute: string): string;
    /**
     * Find all properties in an object that match the predicate.
     * @param obj
     * @param predicate
     * @param parentKey
     */
    findAllDeep<T>(obj: any, predicate: (value: any) => boolean | undefined, parentKey?: string): {
        key: string;
        value: T;
    }[];
    /**
     * Test if `position` is in `range`. If the position is at the edges, will return true.
     * Adapted from core vscode
     * @param range
     * @param position
     */
    rangeContains(range: Range, position: Position): boolean;
    /**
     * Parse an xml file and get back a javascript object containing its results
     * @param text
     */
    parseXml(text: string): Promise<any>;
    propertyCount(object: object): number;
    defer<T>(): {
        promise: Promise<T>;
        resolve: (value?: T | PromiseLike<T>) => void;
        reject: (reason?: any) => void;
    };
    padLeft(subject: string, totalLength: number, char: string): string;
    /**
     * Given a URI, convert that to a regular fs path
     * @param uri
     */
    uriToPath(uri: string): string;
    /**
     * Given a file path, convert it to a URI string
     */
    pathToUri(pathAbsolute: string): string;
    /**
     * Get the outDir from options, taking into account cwd and absolute outFile paths
     * @param options
     */
    getOutDir(options: BrsConfig): string;
    /**
     * Get paths to all files on disc that match this project's source list
     */
    getFilePaths(options: BrsConfig): Promise<{
        src: string;
        dest: string;
    }[]>;
    /**
     * Determine whether this diagnostic should be supressed or not, based on brs comment-flags
     * @param diagnostic
     */
    diagnosticIsSuppressed(diagnostic: Diagnostic): boolean;
    /**
     * Given a string, extract each item split by whitespace
     * @param text
     */
    tokenizeByWhitespace(text: string): {
        startIndex: number;
        text: string;
    }[];
    /**
     * The BRS library uses 1-based line indexes, and 0 based column indexes.
     * However, vscode expects zero-based for everything.
     * @param start - the location.start object from brs
     * @param end - the location.end object from brs
     */
    brsRangeFromPositions(start: BrsPosition, end: BrsPosition): Range;
}
export declare let util: Util;
export default util;
interface BrsPosition {
    line: number;
    column: number;
}
